Select working mode for messages with links, but *without command specified*.
Sane defaults are *Download* for *private chats* and *Ask* for group chats.

Enable *Captions* to send audios *with source captions* and *as replies*.

Enable *Unknown sites* to allow checking unknown sites (will reset in a day).
